@@ -1,4 +1,5 @@
-var _curry3 = /*#__PURE__*/require('./internal/_curry3');
+var _curry3 = require('./internal/_curry3');
+
 
 /**
  * Takes a predicate, a transformation function, and an initial value,
@@ -19,13 +20,10 @@ var _curry3 = /*#__PURE__*/require('./internal/_curry3');
  *
  *      R.until(R.gt(R.__, 100), R.multiply(2))(1) // => 128
  */
-
-
-var until = /*#__PURE__*/_curry3(function until(pred, fn, init) {
+module.exports = _curry3(function until(pred, fn, init) {
   var val = init;
   while (!pred(val)) {
     val = fn(val);
   }
   return val;
 });
-module.exports = until;
\ No newline at end of file
